// -*- c++ -*-

#ifndef __SOUND_PROCESS_H
#define __SOUND_PROCESS_H

#include "CoreOption.h"

extern CoreOptionEntryList soundProcessEntries;


#endif

